import logging


# Configure logging
logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s - %(levelname)s - %(message)s",
    handlers=[logging.StreamHandler()],
)

MIXED_TEXT_THRESHOLD = 0.65  # Threshold for code-mixed text classification
DEFAULT_DETECT_THRESHOLD = 0.85
DEFAULT_NGRAM_RANGE = (1, 6)  # Use character n-grams from 1 to 6
DEFAULT_MAX_FEATURES = 20000

# Languages to help determine Kinyarwanda
HELPER_LANGUAGES = ["kinyarwanda", "english", "french", "swahili", "other"]

# Loan words
EN_LOAN_WORDS = [
    "computer",
    "internet",
    "youtube",
    "testing",
    "software",
    "ok",
    "email",
    "phone",
    "message",
    "app",
    "facebook",
    "whatsapp",
    "online",
    "download",
    "video",
    "tv",
    "radio",
    "bank",
    "office",
    "car",
    "bus",
    "school",
    "university",
    "laptop",
    "charging",
    "class",
    "team",
    "group",
    "project",
    # Add common English verbs used in code-mixing (base forms)
    "test",
    "download",
    "charge",
    "start",
    "stop",
    "check",
    "send",
    "receive",
    "share",
    "like",
    "comment",
    "post",
    "update",
    "join",
    "create",
]

FR_LOAN_WORDS = [
    "bonjour",
    "merci",
    "école",
    "bureau",
    "centre",
    "université",
    "document",
    "voiture",
    "téléphone",
    "restaurant",
    "hôtel",
    "café",
    "police",
    "journal",
    "politique",
    "économie",
    "télévision",
    "hôpital",
    "docteur",
    "infirmière",
]

SW_LOAN_WORDS = [
    "vipi",
    "habari",
    "asante",
    "karibu",
    "tafadhali",
    "nzuri",
    "ndio",
    "hapana",
    "sawa",
    "sana",
    "pole",
    "chakula",
    "maji",
    "rafiki",
    "safari",
    "jambo",
    "kwaheri",
    "mkubwa",
    "mdogo",
    "mzee",
    "bwana",
]


# Kinyarwanda particulars
KINYA_MARKERS = [
    "ndi",
    "uri",
    "ari",
    "turi",
    "muri",
    "bari",  # to be forms
    "nda",
    "ura",
    "ara",
    "tura",
    "mura",
    "bara",  # present continuous markers
    "na",
    "wa",
    "ya",
    "cya",
    "bya",
    "rya",
    "ka",  # possessive markers
    "mu",
    "ku",
    "i",
    "muri",
    "kuri",  # locative prepositions
    "nta",
    "ese",
    "ni",
    "si",  # common particles
    "ubu",
    "ejo",
    "kare",
    "none",
    "nonaha",
    "bwangu",
    "vuba",  # time markers
    "na",
    "kandi",
    "ariko",
    "cyangwa",  # conjunctions
    "ngo",
    "ko",
    "kuko",
    "bitihise",
    "kugira",  # complementizers
    "ba",
    "ma",
    "ki",
    "bi",
    "ru",
    "ka",
    "bu",  # noun class prefixes (some overlap with subject)
    "n",
    "u",
    "a",
    "tu",
    "mu",
    "ba",  # subject prefixes
]

KINYA_AFFIX_SUFFIXES = [
    "nga",
    "mo",
    "ho",
    "yo",
    "ko",
    "ga",
    "ye",
    "yeho",
    "yemo",
    "yeyo",
    "etse",
]
KINYA_AFFIX_PREFIXES = [
    "ku",
    "gu",
    "ba",
    "aba",
    "umu",
    "imi",
    "iki",
    "ibi",
    "in",
    "ama",
    "uru",
    "aka",
    "ubu",
    "ukw",
    "aha",
    "utw",
]

IBIHEKANE = [
    "bw",
    "bg",
    "by",
    "byw",
    "mb",
    "mbw",
    "mby",
    "mbyw",
    "cw",
    "cy",
    "nc",
    "ncw",
    "ncy",
    "dw",
    "nd",
    "ndw",
    "ndy",
    "fw",
    "mf",
    "mfw",
    "gw",
    "ng",
    "ngw",
    "hw",
    "jw",
    "jy",
    "nj",
    "njw",
    "njy",
    "kw",
    "nk",
    "nkw",
    "mw",
    "my",
    "myw",
    "nw",
    "ny",
    "nyw",
    "nny",
    "pw",
    "py",
    "mp",
    "mpw",
    "mpy",
    "pf",
    "pfw",
    "pfy",
    "rw",
    "ry",
    "sw",
    "sy",
    "ns",
    "nsw",
    "nsy",
    "sh",
    "shw",
    "shy",
    "shyw",
    "nsh",
    "nshw",
    "nshy",
    "nshyw",
    "tw",
    "ty",
    "nt",
    "ntw",
    "nty",
    "ts",
    "tsw",
    "vw",
    "vy",
    "mv",
    "mvw",
    "mvy",
    "zw",
    "nz",
    "nzw",
    "mvy",
]

DISTINCTIVE_IBIHEKANE = [
    "nny",
    "mpw",
    "nshw",
    "shyw",
    "mbyw",
    "nshy",
    "nshyw",
    "ndy",
    "mvw",
    "mvy",
    "njw",
    "njy",
    "myw",
    "nzw",
    "ncw",
    "ncy",
]

IBYUNGO = ["na", "nka", "n'", "nk'"]

INGOMBAJWI = [
    "b",
    "c",
    "d",
    "f",
    "g",
    "h",
    "j",
    "k",
    "l",
    "m",
    "n",
    "p",
    "r",
    "s",
    "t",
    "v",
    "w",
    "y",
    "z",
]

COMMON_KINYA_PATTERNS = [
    "rwa",
    "nya",
    "ndi",
    "mbe",
    "cy",
    "by",
    "ry",
    "tw",
    "mw",
    "nda",
    "sha",
    "ngu",
    "nde",
    "mur",
    "uba",
    "iby",
    "icy",
    "uku",
    "uri",
    "ara",
    "ese",
    "ama",
    "ubu",
    "nge",
    "byo",
    "cyo",
    "ryo",
    "kwa",
    "nta",
    "ira",
    "mbw",
    "mby",
    "mbyw",
    "ncy",
    "ndw",
    "ndy",
    "mfw",
    "ngw",
    "njw",
    "njy",
    "nkw",
    "myw",
    "nyw",
    "nny",
    "mpw",
    "mpy",
    "pfw",
    "pfy",
    "nsw",
    "nsy",
    "shw",
    "shy",
    "shyw",
    "nsh",
    "nshw",
    "nshy",
    "nshyw",
    "ntw",
    "nty",
    "tsw",
    "mvw",
    "mvy",
    "nzw",
    "kug",
    "guk",
    "kw",
    "mw",
    "rw",
    "by",
    "cy",  # Added common structures
]


# Data
DEFAULT_OUTPUT_CSV_PATH = "../data/raw/training_data.csv"
TRAINING_DATA_CSV_PATH = "data/raw/spoken_languages_in_rw_05072025.csv"
MODEL_RESOURCE_PATH = "models/kinya_detector.joblib"